Форум БГУИР • Центр пользователя • Регистрация

# Форум БГУИР

Пропустить

Расширенный поиск

Язык:

## Форум БГУИР - Регистрация

Заходя на форум “Форум БГУИР” (в дальнейшем «мы», «нас», «наш», “Форум БГУИР”, “http://www.bsuir.by/conference”), Вы принимаете следующие условия. Если Вы не согласны с одним, или несколькими условиями - пожалуйста, не заходите на форум “Форум БГУИР”. Мы оставляем за собой право изменить данные правила в любое время, и постараемся уведомить Вас об этом. Также, мы рекомендуем Вам периодически обращаться к правилам, чтобы быть в курсе всех изменений. Использование форума «Форум БГУИР» после изменения правил подразумевает Ваше с ними согласие.
Наши форумы работают на платформе phpBB (в дальнейшем “они”, “их”, “программное обеспечение phpBB”, “www.phpbb.com”, “phpBB Group”, “phpBB Teams”), выпущенной в соответствии с лицензией “General Public License” (в дальнейшем “GPL”). Дистрибутив может быть загружен с www.phpbb.com. Разработчики phpBB осуществляют только техническю поддержку и не несут ответственности за материалы, размещенные на форуме и действия администрации. С более детальной информацией можно ознакомиться на http://www.phpbb.com/.
Вы подтверждаете своё согласие не размещать сообщения оскорбительного, нецензурного, порнографического характера, угроз и призывов к национальной розни, а также прочих материалов, нарушаюших законы Вашей страны, страны, которая предоставляет услуги хостинга для форума “Форум БГУИР”, или международного законодательства. В случае размещения подобных сообщений, администрация форума может заблокировать Ваш аккаунт и поставить об этом в известность Вашего провайдера. С этой целью сохраняются IP адреса всех сообщений. Вы соглашаетесь с тем, что администрация “Форум БГУИР” оставляет за собой право в любое время по своему усмотрению переместить, закрыть, редактировать, или удалить любую тему на форуме. Как пользователь, Вы соглашаетесь с тем, что вся указанная Вами информация будет храниться в базе данных. В то же время, данная информация не будет доступна третьим лицам без Вашего согласия, администрация “Форум БГУИР” и phpBB не несут ответственности за действия хакеров, которые могут получить доступ к этой информации вследствие взлома.